==> ejc-outcontract-impl-3.0.0-20220808.015611-93-sources.jar: com/ejianc/foundation/bidWinDisclosure/bean/BidWinDisclosureEntity.java <==
package com.ejianc.foundation.bidWinDisclosure.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 中标交底
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_win_disclosure")
public class BidWinDisclosureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="project_address")
    private String projectAddress; // 工程地点
    @TableField(value="bid_win_mny")
    private BigDecimal bidWinMny; // 中标金额
    @TableField(value="construction_area")
    private BigDecimal constructionArea; // 建筑面积
    @TableField(value="confess_address")
    private String confessAddress; // 交底地点
    @TableField(value="confess_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date confessDate; // 交底时间
    @TableField(value="confidant")
    private String confidant; // 交底人
    @TableField(value="receiver")
    private String receiver; // 接收人
    @TableField(value="project_overview")
    private String projectOverview; // 工程概况
    @TableField(value="quoted_price_data")
    private String quotedPriceData; // 本工程投标报价依据的资料
    @TableField(value="should_save_data")
    private String shouldSaveData; // 所属公司和项目部应该保存的资料
    @TableField(value="quote_ideas")
    private String quoteIdeas; // 报价的整体思路
    @TableField(value="quote_adjustment_item")
    private String quoteAdjustmentItem; // 报价时主要调增，调减的子目
    @TableField(value="memo")
    private String memo; // 备注
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public BigDecimal getBidWinMny() {
        return bidWinMny;
    }

    public void setBidWinMny(BigDecimal bidWinMny) {
        this.bidWinMny = bidWinMny;
    }
    public BigDecimal getConstructionArea() {
        return constructionArea;
    }

    public void setConstructionArea(BigDecimal constructionArea) {
        this.constructionArea = constructionArea;
    }
    public String getConfessAddress() {
        return confessAddress;
    }

    public void setConfessAddress(String confessAddress) {
        this.confessAddress = confessAddress;
    }
    public Date getConfessDate() {
        return confessDate;
    }

    public void setConfessDate(Date confessDate) {
        this.confessDate = confessDate;
    }
    public String getConfidant() {
        return confidant;
    }

    public void setConfidant(String confidant) {
        this.confidant = confidant;
    }
    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getProjectOverview() {
        return projectOverview;
    }

    public void setProjectOverview(String projectOverview) {
        this.projectOverview = projectOverview;
    }
    public String getQuotedPriceData() {
        return quotedPriceData;
    }

    public void setQuotedPriceData(String quotedPriceData) {
        this.quotedPriceData = quotedPriceData;
    }
    public String getShouldSaveData() {
        return shouldSaveData;
    }

    public void setShouldSaveData(String shouldSaveData) {
        this.shouldSaveData = shouldSaveData;
    }
    public String getQuoteIdeas() {
        return quoteIdeas;
    }

    public void setQuoteIdeas(String quoteIdeas) {
        this.quoteIdeas = quoteIdeas;
    }
    public String getQuoteAdjustmentItem() {
        return quoteAdjustmentItem;
    }

    public void setQuoteAdjustmentItem(String quoteAdjustmentItem) {
        this.quoteAdjustmentItem = quoteAdjustmentItem;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20230711.074955-176-sources.jar: com/ejianc/foundation/bidWinDisclosure/bean/BidWinDisclosureEntity.java <==
package com.ejianc.foundation.bidWinDisclosure.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 中标交底
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_win_disclosure")
public class BidWinDisclosureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="project_address")
    private String projectAddress; // 工程地点
    @TableField(value="bid_win_mny")
    private BigDecimal bidWinMny; // 中标金额
    @TableField(value="construction_area")
    private String constructionArea; // 建筑面积
    @TableField(value="confess_address")
    private String confessAddress; // 交底地点
    @TableField(value="confess_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date confessDate; // 交底时间
    @TableField(value="confidant")
    private String confidant; // 交底人
    @TableField(value="receiver")
    private String receiver; // 接收人
    @TableField(value="project_overview")
    private String projectOverview; // 工程概况
    @TableField(value="quoted_price_data")
    private String quotedPriceData; // 本工程投标报价依据的资料
    @TableField(value="should_save_data")
    private String shouldSaveData; // 所属公司和项目部应该保存的资料
    @TableField(value="quote_ideas")
    private String quoteIdeas; // 报价的整体思路
    @TableField(value="quote_adjustment_item")
    private String quoteAdjustmentItem; // 报价时主要调增，调减的子目
    @TableField(value="memo")
    private String memo; // 备注
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public BigDecimal getBidWinMny() {
        return bidWinMny;
    }

    public void setBidWinMny(BigDecimal bidWinMny) {
        this.bidWinMny = bidWinMny;
    }
    public String getConstructionArea() {
        return constructionArea;
    }

    public void setConstructionArea(String constructionArea) {
        this.constructionArea = constructionArea;
    }
    public String getConfessAddress() {
        return confessAddress;
    }

    public void setConfessAddress(String confessAddress) {
        this.confessAddress = confessAddress;
    }
    public Date getConfessDate() {
        return confessDate;
    }

    public void setConfessDate(Date confessDate) {
        this.confessDate = confessDate;
    }
    public String getConfidant() {
        return confidant;
    }

    public void setConfidant(String confidant) {
        this.confidant = confidant;
    }
    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getProjectOverview() {
        return projectOverview;
    }

    public void setProjectOverview(String projectOverview) {
        this.projectOverview = projectOverview;
    }
    public String getQuotedPriceData() {
        return quotedPriceData;
    }

    public void setQuotedPriceData(String quotedPriceData) {
        this.quotedPriceData = quotedPriceData;
    }
    public String getShouldSaveData() {
        return shouldSaveData;
    }

    public void setShouldSaveData(String shouldSaveData) {
        this.shouldSaveData = shouldSaveData;
    }
    public String getQuoteIdeas() {
        return quoteIdeas;
    }

    public void setQuoteIdeas(String quoteIdeas) {
        this.quoteIdeas = quoteIdeas;
    }
    public String getQuoteAdjustmentItem() {
        return quoteAdjustmentItem;
    }

    public void setQuoteAdjustmentItem(String quoteAdjustmentItem) {
        this.quoteAdjustmentItem = quoteAdjustmentItem;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
